<?php

namespace Marius\RealEstate1.0\Policies;

use Litepie\User\Contracts\UserPolicy;
use Marius\RealEstate1.0\Models\AdProp;

class AdPropPolicy
{

    /**
     * Determine if the given user can view the ad_prop.
     *
     * @param UserPolicy $user
     * @param AdProp $ad_prop
     *
     * @return bool
     */
    public function view(UserPolicy $user, AdProp $ad_prop)
    {
        if ($user->canDo('real_estate1.0.ad_prop.view') && $user->isAdmin()) {
            return true;
        }

        return $ad_prop->user_id == user_id() && $ad_prop->user_type == user_type();
    }

    /**
     * Determine if the given user can create a ad_prop.
     *
     * @param UserPolicy $user
     * @param AdProp $ad_prop
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('real_estate1.0.ad_prop.create');
    }

    /**
     * Determine if the given user can update the given ad_prop.
     *
     * @param UserPolicy $user
     * @param AdProp $ad_prop
     *
     * @return bool
     */
    public function update(UserPolicy $user, AdProp $ad_prop)
    {
        if ($user->canDo('real_estate1.0.ad_prop.edit') && $user->isAdmin()) {
            return true;
        }

        return $ad_prop->user_id == user_id() && $ad_prop->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given ad_prop.
     *
     * @param UserPolicy $user
     * @param AdProp $ad_prop
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, AdProp $ad_prop)
    {
        return $ad_prop->user_id == user_id() && $ad_prop->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given ad_prop.
     *
     * @param UserPolicy $user
     * @param AdProp $ad_prop
     *
     * @return bool
     */
    public function verify(UserPolicy $user, AdProp $ad_prop)
    {
        if ($user->canDo('real_estate1.0.ad_prop.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given ad_prop.
     *
     * @param UserPolicy $user
     * @param AdProp $ad_prop
     *
     * @return bool
     */
    public function approve(UserPolicy $user, AdProp $ad_prop)
    {
        if ($user->canDo('real_estate1.0.ad_prop.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
